<?php
// $Id: template.php,v 1.1.2.4 2010/09/11 01:24:58 mtecknology Exp $

/**
 * @file
 * Core functions for the operations of the theme
 */

/**
 * Index
 * 1. Theme Settings
 * 2. PHP Template Functions
 * 3. UD Functions
 */

/**
 * 1. Theme Settings
 */

if (is_null(theme_get_setting('wrapper_width'))) {
  global $theme_key;

  $defaults = array(
    'wrapper_width' => 980,
    'width_type' => '0',
    'display_help' => '1',
    'ubuntu_footer' => '1',
    'udtheme_style' => 'classic-brown',
    'udtheme_trademark' => '0',
  );

  $settings = theme_get_settings($theme_key);

  if (module_exists('node')) {
    foreach (node_get_types() as $type => $name) {
      unset($settings['toggle_node_info_' . $type]);
    }
  }

  variable_set(
    str_replace('/', '_', 'theme_'. $theme_key .'_settings'),
    array_merge($defaults, $settings)
  );

  theme_get_setting('', TRUE);
}

/**
 * 2. PHP Template Functions
 */

/**
 * hook_preprocess_search_theme_form()
 * Override display of search form.
 */
function udtheme_preprocess_search_theme_form(&$vars, $hook) {
  $vars['form']['search_theme_form']['#title'] = '';
  $vars['form']['search_theme_form']['#value'] = t('Search...');
  $vars['form']['submit']['#value'] = t('Go');
  unset($vars['form']['search_theme_form']['#printed']);
  $vars['search']['search_theme_form'] = drupal_render($vars['form']['search_theme_form']);
  unset($vars['form']['submit']['#printed']);
  $vars['search']['submit'] = drupal_render($vars['form']['submit']);
  $vars['search_form'] = implode($vars['search']);
}

/**
 * hook_preprocess_search_block_form()
 * Override display of search block.
 */
function udtheme_preprocess_search_block_form(&$vars, $hook) {
  $vars['form']['search_block_form']['#title'] = '';
  $vars['form']['search_block_form']['#value'] = t('Search...');
  $vars['form']['submit']['#value'] = t('Go');
  unset($vars['form']['search_block_form']['#printed']);
  $vars['search']['search_block_form'] = drupal_render($vars['form']['search_block_form']);
  unset($vars['form']['submit']['#printed']);
  $vars['search']['submit'] = drupal_render($vars['form']['submit']);
  $vars['search_form'] = implode($vars['search']);
}

/**
 * hook_preprocess_page
 * Generate / override exsisting variables
 */
function udtheme_preprocess_page(&$vars) {
  $pallette = udtheme_pallette();

  $vars['menu']         = udtheme_whichmenu($vars['primary_links']);
  $vars['logo']         = udtheme_buildlogo($vars);
  $vars['footer']       = udtheme_footer($vars['footer_message']);
  $vars['help_text']    = udtheme_help($vars['help']);
  $vars['trademark']    = udtheme_trademark();

  if ($pallette && !$vars['trademark']) {
    $vars['css']        = drupal_add_css($pallette);
    $vars['styles']     = drupal_get_css();
  }
}

/**
 * 3. UD Functions
 */

/**
 * Automatically use the nice_menu module if available
 * If not available, no drop downs will be displayed
 */
function udtheme_whichmenu($primary_links) {
  if (module_exists('nice_menus')) {
    // Nice Menu
    $menu = theme('nice_menus_primary_links', $primary_links);
    if (!isset($menu)) {
      // This is deprecated in the latest nice_menus module.
      $menu = theme('nice_menu_primary_links', $primary_links);
    }
  }
  else {
    // Standard Menu
    $menu = theme('links', $primary_links);
  }

  if (isset($menu)) {
    return $menu;
  }
}

/**
 * Generate a logo if the variable exists
 */
function udtheme_buildlogo($vars) {
  if ($vars['logo']) {
    $logo = '<div id="logo">' .
            '  <a href="' . check_url($vars['front_page']) . '" title="' . $vars['site_name'] . '">' .
            '    <img src="' . check_url($vars['logo']) . '" alt="' . $vars['site_name'] . '" />' .
            '  </a>' .
            '</div>';
  }
  if (isset($logo)) {
    return $logo;
  }
}

/**
 * Generate a or use the default if one has not been set
 */
function udtheme_footer($footmsg) {
  if (!isset($footmsg) || $footmsg == '') {
    $footmsg = t('<div class="block"><h2>@legal</h2> !copy </div>'
                 . '<div class="block"><h2>@more</h2>!getubuntu !brainstorm !forums !spread </div>',
                 array(
                   '@legal' => t('Legal Disclaimer'),
                   '!copy' => t('&copy; 2010 Canonical Ltd. Ubuntu and Canonical are registered trademarks of Canonical Ltd.'),
                   '@more' => t('More Ubuntu'),
                   '!getubuntu' => l(t('Get Ubuntu'), 'http://ubuntu.com/getubuntu/download/'),
                   '!brainstorm' => l(t('Ubuntu Brainstorm'), 'http://brainstorm.ubuntu.com/'),
                   '!forums' => l(t('Ubuntu Forums'), 'http://ubuntuforums.org/'),
                   '!spread' => l(t('Spread Ubuntu'), 'http://spreadubuntu.neomenlo.org/'),
                 )
               ) . $footmsg;
  }

  return $footmsg;
}

/**
 * Theme setting to either show or hide extra help
 */
function udtheme_help($help = NULL) {
  return theme_get_setting('display_help', 1) ? $help : NULL;
}

/**
 * Code to handle things needing a static width
 */
function pagewidth() {
  $type = theme_get_setting('width_type', 0) == 1 ? '%' : 'px';
  return theme_get_setting('wrapper_width', 980) . $type;
}

/**
 * Return style sheet theme to be added to base style
 */
function udtheme_pallette() {
  /** NOTE: This will be possible in Drupal 7.x. **/

  //if (theme_get_setting('udtheme_trademark', FALSE)) {
  //  return 'http://edge.launchpad.net/ubuntu-drupal-theme/trademark/6.7.0/+download/trademark-rtl.css';
  //}
  //else {
    return path_to_theme() . '/styles/' . theme_get_setting('udtheme_style', 'classic-brown') . '.css';
  //}
}

/**
 * Add CSS for trademarked sites.
 * In Drupal 7.x this wil be moved into udtheme_pallette but can't be done at this point.
 */
function udtheme_trademark() {
  global $language;

  if (theme_get_setting('udtheme_trademark', FALSE)) {
    $css = '<link rel="stylesheet" type="text/css" href="http://edge.launchpad.net/ubuntu-drupal-theme/trademark/6.7.0/+download/trademark.css" />' . PHP_EOL;
    if ($language->direction == LANGUAGE_RTL) {
      $css = '<link rel="stylesheet" type="text/css" href="http://edge.launchpad.net/ubuntu-drupal-theme/trademark/6.7.0/+download/trademark-rtl.css" />' . PHP_EOL;
    }
  }

  return $css;
}


/**
 * Sets the body-tag class attribute.
 * Adds 'sidebar-left', 'sidebar-right' or 'sidebars' classes as needed.
 */
function udtheme_body_class($left = '', $right = '') {
  if ($left != '' && $right != '') {
    $class = 'sidebars';
  }
  elseif ($left != '' && $right == '') {
    $class = 'sidebar-left';
  }
  elseif ($left == '' && $right != '') {
    $class = 'sidebar-right';
  }

  if (isset($class)) {
    return ' class="'. $class .'"';
  }
}
